@@ -24,6 +24,11 @@ register_backend(
     "dogpile.cache.backends.memcached",
     "MemcachedBackend",
 )
+register_backend(
+    "dogpile.cache.pymemcache",
+    "dogpile.cache.backends.memcached",
+    "PyMemcacheBackend",
+)
 register_backend(
     "dogpile.cache.memory", "dogpile.cache.backends.memory", "MemoryBackend"
 )
@@ -36,6 +41,7 @@ register_backend(
     "dogpile.cache.redis", "dogpile.cache.backends.redis", "RedisBackend"
 )
 register_backend(
-    "dogpile.cache.redis_sentinel", "dogpile.cache.backends.redis",
-    "RedisSentinelBackend"
+    "dogpile.cache.redis_sentinel",
+    "dogpile.cache.backends.redis",
+    "RedisSentinelBackend",
 )
