@@ -25,4 +25,4 @@ start, end = int(sys.argv[1]), int(sys.argv[2])
 
 dir_ = os.getcwd()
 
-print(hash(dir_) % (end - start)) + start
+print((hash(dir_) % (end - start)) + start)
