@@ -1,8 +1,5 @@
 import re
-import pytest
-from functools import wraps
-from dogpile.util import compat
-from dogpile.util.compat import configparser, io  # noqa
+import sys
 import time
 
 
@@ -33,14 +30,5 @@ def winsleep():
     # sleep a for an amount of time
     # sufficient for windows time.time()
     # to change
-    if compat.win32:
-        time.sleep(.001)
-
-
-def requires_py3k(fn):
-    @wraps(fn)
-    def wrap(*arg, **kw):
-        if compat.py2k:
-            pytest.skip("Python 3 required")
-        return fn(*arg, **kw)
-    return wrap
+    if sys.platform.startswith("win"):
+        time.sleep(0.001)
