@@ -1,16 +1,19 @@
 import collections
 import itertools
+import json
 import random
 from threading import Lock
 from threading import Thread
 import time
 from unittest import TestCase
+import uuid
 
 import pytest
 
 from dogpile.cache import CacheRegion
 from dogpile.cache import register_backend
 from dogpile.cache.api import CacheBackend
+from dogpile.cache.api import CacheMutex
 from dogpile.cache.api import NO_VALUE
 from dogpile.cache.region import _backend_loader
 from . import assert_raises_message
@@ -42,6 +45,7 @@ class _GenericBackendFixture(object):
 
     region_args = {}
     config_args = {}
+    extra_arguments = {}
 
     _region_inst = None
     _backend_inst = None
@@ -49,7 +53,15 @@ class _GenericBackendFixture(object):
     _keys = set()
 
     def _region(self, backend=None, region_args={}, config_args={}):
-        _region_args = self.region_args.copy()
+        _region_args = {}
+
+        # TODO: maybe we use a class-level naming convention instead
+        # of a dict here so that arguments merge naturally
+
+        for cls in reversed(self.__class__.__mro__):
+            if "region_args" in cls.__dict__:
+                _region_args.update(cls.__dict__["region_args"])
+
         _region_args.update(**region_args)
         _config_args = self.config_args.copy()
         _config_args.update(config_args)
@@ -73,6 +85,7 @@ class _GenericBackendFixture(object):
         backend_cls = _backend_loader.load(self.backend)
         _config_args = self.config_args.copy()
         arguments = _config_args.get("arguments", {})
+        arguments = {**arguments, **self.extra_arguments}
         self._backend_inst = backend_cls(arguments)
         return self._backend_inst
 
@@ -80,7 +93,7 @@ class _GenericBackendFixture(object):
 class _GenericBackendTest(_GenericBackendFixture, TestCase):
     def test_backend_get_nothing(self):
         backend = self._backend()
-        eq_(backend.get("some_key"), NO_VALUE)
+        eq_(backend.get_serialized("some_key"), NO_VALUE)
 
     def test_backend_delete_nothing(self):
         backend = self._backend()
@@ -88,14 +101,29 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
 
     def test_backend_set_get_value(self):
         backend = self._backend()
-        backend.set("some_key", "some value")
-        eq_(backend.get("some_key"), "some value")
+        backend.set_serialized("some_key", b"some value")
+        eq_(backend.get_serialized("some_key"), b"some value")
 
     def test_backend_delete(self):
         backend = self._backend()
-        backend.set("some_key", "some value")
+        backend.set_serialized("some_key", b"some value")
         backend.delete("some_key")
-        eq_(backend.get("some_key"), NO_VALUE)
+        eq_(backend.get_serialized("some_key"), NO_VALUE)
+
+    def test_region_is_key_locked(self):
+        reg = self._region()
+        random_key = str(uuid.uuid1())
+        assert not reg.get(random_key)
+        eq_(reg.key_is_locked(random_key), False)
+        # ensures that calling key_is_locked doesn't acquire the lock
+        eq_(reg.key_is_locked(random_key), False)
+
+        mutex = reg.backend.get_mutex(random_key)
+        if mutex:
+            mutex.acquire()
+            eq_(reg.key_is_locked(random_key), True)
+            mutex.release()
+            eq_(reg.key_is_locked(random_key), False)
 
     def test_region_set_get_value(self):
         reg = self._region()
@@ -184,6 +212,7 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
 
         eq_(reg.get_or_create("some key", creator), "some value")
 
+    @pytest.mark.time_intensive
     def test_threaded_dogpile(self):
         # run a basic dogpile concurrency test.
         # note the concurrency of dogpile itself
@@ -214,8 +243,19 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
         if not reg.backend.has_lock_timeout():
             assert False not in canary
 
+    @pytest.mark.time_intensive
     def test_threaded_get_multi(self):
+        """This test is testing that when we get inside the "creator" for
+        a certain key, there are no other "creators" running at all for
+        that key.
+
+        With "distributed" locks, this is not 100% the case.
+
+        """
         reg = self._region(config_args={"expiration_time": 0.25})
+        backend_mutex = reg.backend.get_mutex("some_key")
+        is_custom_mutex = backend_mutex is not None
+
         locks = dict((str(i), Lock()) for i in range(11))
 
         canary = collections.defaultdict(list)
@@ -252,7 +292,7 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
                 time.sleep(0.5)
 
         f()
-        return
+
         threads = [Thread(target=f) for i in range(5)]
         for t in threads:
             t.start()
@@ -260,8 +300,12 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
             t.join()
 
         assert sum([len(v) for v in canary.values()]) > 10
-        for l in canary.values():
-            assert False not in l
+
+        # for non-custom mutex, check that we never had two creators
+        # running at once
+        if not is_custom_mutex:
+            for l in canary.values():
+                assert False not in l
 
     def test_region_delete(self):
         reg = self._region()
@@ -270,6 +314,7 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
         reg.delete("some key")
         eq_(reg.get("some key"), NO_VALUE)
 
+    @pytest.mark.time_intensive
     def test_region_expire(self):
         # TODO: ideally tests like these would not be using actual
         # time(); instead, an artificial function where the increment
@@ -278,19 +323,24 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
         # with very slow processing missing a timeout, as is often the
         # case with this particular test
 
-        reg = self._region(config_args={"expiration_time": 0.75})
+        expire_time = 1.00
+
+        reg = self._region(config_args={"expiration_time": expire_time})
         counter = itertools.count(1)
 
         def creator():
             return "some value %d" % next(counter)
 
         eq_(reg.get_or_create("some key", creator), "some value 1")
-        time.sleep(0.85)
+        time.sleep(expire_time + (0.2 * expire_time))
         # expiration is definitely hit
-        eq_(reg.get("some key", ignore_expiration=True), "some value 1")
+        post_expiration = reg.get("some key", ignore_expiration=True)
+        if post_expiration is not NO_VALUE:
+            eq_(post_expiration, "some value 1")
+
         eq_(reg.get_or_create("some key", creator), "some value 2")
 
-        # this line needs to run less the .75 sec before the previous
+        # this line needs to run less the expire_time sec before the previous
         # two or it hits the expiration
         eq_(reg.get("some key"), "some value 2")
 
@@ -330,20 +380,68 @@ class _GenericBackendTest(_GenericBackendFixture, TestCase):
         )
 
 
+class _GenericSerializerTest(TestCase):
+    # Inheriting from this class will make test cases
+    # use these serialization arguments
+    region_args = {
+        "serializer": lambda v: json.dumps(v).encode("ascii"),
+        "deserializer": json.loads,
+    }
+
+    def test_uses_serializer(self):
+        region = self._region()
+
+        backend = region.backend
+        value = {"foo": ["bar", 1, False, None]}
+        region.set("k", value)
+
+        raw = backend.get_serialized("k")
+
+        assert isinstance(raw, bytes)
+
+        pipe = raw.find(b"|")
+        payload = raw[pipe + 1 :]
+        eq_(payload, self.region_args["serializer"](value))
+        eq_(region._parse_serialized_from_backend(raw).payload, value)
+
+    def test_uses_deserializer(self):
+        region = self._region()
+
+        value = {"foo": ["bar", 1, False, None]}
+        region.set("k", value)
+
+        asserted = region.get("k")
+
+        eq_(asserted, value)
+
+    # TODO: test set_multi, get_multi
+
+
 class _GenericMutexTest(_GenericBackendFixture, TestCase):
     def test_mutex(self):
         backend = self._backend()
         mutex = backend.get_mutex("foo")
 
+        assert not mutex.locked()
         ac = mutex.acquire()
         assert ac
         ac2 = mutex.acquire(False)
+        assert mutex.locked()
         assert not ac2
         mutex.release()
+        assert not mutex.locked()
+
         ac3 = mutex.acquire()
         assert ac3
         mutex.release()
 
+    def test_subclass_match(self):
+        backend = self._backend()
+        mutex = backend.get_mutex("foo")
+
+        assert isinstance(mutex, CacheMutex)
+
+    @pytest.mark.time_intensive
     def test_mutex_threaded(self):
         backend = self._backend()
         backend.get_mutex("foo")
@@ -411,6 +509,9 @@ class MockMutex(object):
     def release(self):
         return
 
+    def locked(self):
+        return False
+
 
 class MockBackend(CacheBackend):
     def __init__(self, arguments):
