@@ -2,10 +2,12 @@ import os
 import sys
 
 from dogpile.cache.backends.file import AbstractFileLock
+from dogpile.cache.proxy import ProxyBackend
 from dogpile.util.readwrite_lock import ReadWriteMutex
 from . import assert_raises_message
 from ._fixtures import _GenericBackendTest
 from ._fixtures import _GenericMutexTest
+from ._fixtures import _GenericSerializerTest
 
 try:
     import fcntl  # noqa
@@ -52,6 +54,21 @@ class DBMBackendConditionTest(_GenericBackendTest):
     }
 
 
+class DBMBackendProxyTest(_GenericBackendTest):
+    backend = "dogpile.cache.dbm"
+
+    config_args = {
+        "arguments": {"filename": test_fname, "lock_factory": MutexLock},
+        "wrap": [ProxyBackend],
+    }
+
+
+class DBMBackendSerializerTest(
+    _GenericSerializerTest, DBMBackendConditionTest
+):
+    pass
+
+
 class DBMBackendNoLockTest(_GenericBackendTest):
     backend = "dogpile.cache.dbm"
 
