@@ -380,7 +380,11 @@ class MockMemcacheBackend(MemcachedBackend):
         pass
 
     def _create_client(self):
-        return MockClient(self.url)
+        return MockClient(
+            self.url,
+            dead_retry=self.dead_retry,
+            socket_timeout=self.socket_timeout,
+        )
 
 
 class MockPylibmcBackend(PylibmcBackend):
@@ -422,6 +426,24 @@ class MockClient(object):
         self._cache.pop(key, None)
 
 
+class MemcachedBackendTest(TestCase):
+    def test_memcached_dead_retry(self):
+        config_args = {
+            "url": "127.0.0.1:11211",
+            "dead_retry": 4,
+        }
+        backend = MockMemcacheBackend(arguments=config_args)
+        eq_(backend._create_client().kw["dead_retry"], 4)
+
+    def test_memcached_socket_timeout(self):
+        config_args = {
+            "url": "127.0.0.1:11211",
+            "socket_timeout": 6,
+        }
+        backend = MockMemcacheBackend(arguments=config_args)
+        eq_(backend._create_client().kw["socket_timeout"], 6)
+
+
 class PylibmcArgsTest(TestCase):
     def test_binary_flag(self):
         backend = MockPylibmcBackend(arguments={"url": "foo", "binary": True})
