@@ -13,6 +13,7 @@ from dogpile.cache import make_region
 from dogpile.cache import util
 from dogpile.cache.api import CacheBackend
 from dogpile.cache.api import CachedValue
+from dogpile.cache.api import CacheMutex
 from dogpile.cache.api import NO_VALUE
 from dogpile.cache.proxy import ProxyBackend
 from dogpile.cache.region import _backend_loader
@@ -201,6 +202,11 @@ class RegionTest(TestCase):
 
         eq_(reg.get_or_create("some key", creator), "some value")
 
+    def test_key_is_locked(self):
+        reg = self._region()
+
+        eq_(reg.key_is_locked("some key"), False)
+
     def test_multi_creator(self):
         reg = self._region()
 
@@ -399,8 +405,9 @@ class RegionTest(TestCase):
         ret = reg.get_or_create_multi([1, 2], creator)
         eq_(ret, [2, 2])
 
-    def test_soft_invalidate_requires_expire_time_get(self):
+    def test_soft_invalidate_requires_expire_time_get_first_call(self):
         reg = self._region()
+
         reg.invalidate(hard=False)
         assert_raises_message(
             exception.DogpileCacheException,
@@ -410,7 +417,20 @@ class RegionTest(TestCase):
             lambda: "x",
         )
 
-    def test_soft_invalidate_requires_expire_time_get_multi(self):
+    def test_soft_invalidate_requires_expire_time_get_second_call(self):
+        reg = self._region()
+        reg.get_or_create("some key", lambda: "x")
+
+        reg.invalidate(hard=False)
+        assert_raises_message(
+            exception.DogpileCacheException,
+            "Non-None expiration time required for soft invalidation",
+            reg.get_or_create,
+            "some key",
+            lambda: "x",
+        )
+
+    def test_soft_invalidate_requires_expire_time_get_multi_first_call(self):
         reg = self._region()
         reg.invalidate(hard=False)
         assert_raises_message(
@@ -418,7 +438,20 @@ class RegionTest(TestCase):
             "Non-None expiration time required for soft invalidation",
             reg.get_or_create_multi,
             ["k1", "k2"],
-            lambda k: "x",
+            lambda *k: ["x" for key in k],
+        )
+
+    def test_soft_invalidate_requires_expire_time_get_multi_second_call(self):
+        reg = self._region()
+        reg.get_or_create_multi(["k1", "k2"], lambda *k: ["x" for key in k])
+
+        reg.invalidate(hard=False)
+        assert_raises_message(
+            exception.DogpileCacheException,
+            "Non-None expiration time required for soft invalidation",
+            reg.get_or_create_multi,
+            ["k1", "k2"],
+            lambda *k: ["x" for key in k],
         )
 
     def test_should_cache_fn(self):
@@ -504,9 +537,9 @@ class RegionTest(TestCase):
 
 class ProxyRegionTest(RegionTest):
 
-    """ This is exactly the same as the region test above, but it goes through
+    """This is exactly the same as the region test above, but it goes through
     a dummy proxy.  The purpose of this is to make sure the tests  still run
-    successfully even when there is a proxy """
+    successfully even when there is a proxy"""
 
     class MockProxy(ProxyBackend):
         @property
@@ -578,6 +611,37 @@ class TestProxyValue(object):
         self.value = value
 
 
+class MutexAPITest(TestCase):
+    def test_mutex_non_match(self):
+        assert not isinstance(5, CacheMutex)
+        assert not isinstance("some string", CacheMutex)
+
+        class Foo:
+            def release(self):
+                pass
+
+        assert not isinstance(Foo(), CacheMutex)
+
+        class Bar:
+            def acquire(self):
+                pass
+
+        assert not isinstance(Bar(), CacheMutex)
+
+    def test_mutex_match(self):
+        class Foo:
+            def acquire(self):
+                # note we are missing the "wait" parameter.  not sure
+                # how ABCs are supposed to efficiently test these
+                # things.
+                pass
+
+            def release(self):
+                pass
+
+        assert isinstance(Foo(), CacheMutex)
+
+
 class AsyncCreatorTest(TestCase):
     def _fixture(self):
         def async_creation_runner(cache, somekey, creator, mutex):
@@ -693,7 +757,7 @@ class ProxyBackendTest(TestCase):
 
     class UsedKeysProxy(ProxyBackend):
 
-        """ Keep a counter of hose often we set a particular key"""
+        """Keep a counter of hose often we set a particular key"""
 
         def __init__(self, *args, **kwargs):
             super(ProxyBackendTest.UsedKeysProxy, self).__init__(
@@ -710,8 +774,8 @@ class ProxyBackendTest(TestCase):
 
     class NeverSetProxy(ProxyBackend):
 
-        """ A totally contrived example of a Proxy that we pass arguments to.
-        Never set a key that matches never_set """
+        """A totally contrived example of a Proxy that we pass arguments to.
+        Never set a key that matches never_set"""
 
         def __init__(self, never_set, *args, **kwargs):
             super(ProxyBackendTest.NeverSetProxy, self).__init__(
