@@ -1,8 +1,9 @@
-from _pytest.unittest import UnitTestCase
-import sys
 import logging
-
 import logging.config
+import sys
+
+from _pytest.unittest import UnitTestCase
+
 logging.config.fileConfig("log_tests.ini")
 
 
@@ -12,19 +13,19 @@ def is_unittest(obj):
     Lifted from older versions of py.test, as this seems to be removed.
 
     """
-    unittest = sys.modules.get('unittest')
+    unittest = sys.modules.get("unittest")
     if unittest is None:
         return  # nobody can have derived unittest.TestCase
     try:
         return issubclass(obj, unittest.TestCase)
     except KeyboardInterrupt:
         raise
-    except:
+    except Exception:
         return False
 
 
 def pytest_pycollect_makeitem(collector, name, obj):
     if is_unittest(obj) and not obj.__name__.startswith("_"):
-        return UnitTestCase(name, parent=collector)
+        return UnitTestCase.from_parent(collector, name=name)
     else:
         return []
